Documentation
¶
Overview ¶
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Package mocks is a generated GoMock package.
Index ¶
- type MockCloner
- type MockClonerMockRecorder
- type MockConfiguration
- func (m *MockConfiguration) All() map[string]any
- func (m *MockConfiguration) EXPECT() *MockConfigurationMockRecorder
- func (m *MockConfiguration) Environment() string
- func (m *MockConfiguration) Get(key string) any
- func (m *MockConfiguration) GetBool(key string) bool
- func (m *MockConfiguration) GetConfigSummary() string
- func (m *MockConfiguration) GetDuration(key string) time.Duration
- func (m *MockConfiguration) GetFloat(key string) float64
- func (m *MockConfiguration) GetInt(key string) int
- func (m *MockConfiguration) GetString(key string) string
- func (m *MockConfiguration) Has(key string) bool
- func (m *MockConfiguration) Load() error
- func (m *MockConfiguration) LoadWithDefaults(defaults map[string]any) error
- func (m *MockConfiguration) Logging() interfaces.LoggingConfig
- func (m *MockConfiguration) Pipeline() interfaces.PipelineConfig
- func (m *MockConfiguration) Registry() interfaces.RegistryConfig
- func (m *MockConfiguration) Security() interfaces.SecurityConfig
- func (m *MockConfiguration) Set(key string, value any)
- func (m *MockConfiguration) Validate() error
- type MockConfigurationMockRecorder
- func (mr *MockConfigurationMockRecorder) All() *gomock.Call
- func (mr *MockConfigurationMockRecorder) Environment() *gomock.Call
- func (mr *MockConfigurationMockRecorder) Get(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) GetBool(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) GetConfigSummary() *gomock.Call
- func (mr *MockConfigurationMockRecorder) GetDuration(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) GetFloat(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) GetInt(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) GetString(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) Has(key any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) Load() *gomock.Call
- func (mr *MockConfigurationMockRecorder) LoadWithDefaults(defaults any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) Logging() *gomock.Call
- func (mr *MockConfigurationMockRecorder) Pipeline() *gomock.Call
- func (mr *MockConfigurationMockRecorder) Registry() *gomock.Call
- func (mr *MockConfigurationMockRecorder) Security() *gomock.Call
- func (mr *MockConfigurationMockRecorder) Set(key, value any) *gomock.Call
- func (mr *MockConfigurationMockRecorder) Validate() *gomock.Call
- type MockContainer
- func (m *MockContainer) EXPECT() *MockContainerMockRecorder
- func (m *MockContainer) Get(name string) (any, error)
- func (m *MockContainer) GetLinter() (interfaces.Linter, error)
- func (m *MockContainer) GetLogger() (interfaces.Logger, error)
- func (m *MockContainer) GetRegistryAuth() (string, string, error)
- func (m *MockContainer) GetRegistryConfig() (interfaces.RegistryConfig, error)
- func (m *MockContainer) GetVulnChecker() (interfaces.VulnChecker, error)
- func (m *MockContainer) Register(name string, factory func() (any, error))
- func (m *MockContainer) Start(ctx context.Context) error
- func (m *MockContainer) Stop(ctx context.Context) error
- func (m *MockContainer) Validate() error
- type MockContainerMockRecorder
- func (mr *MockContainerMockRecorder) Get(name any) *gomock.Call
- func (mr *MockContainerMockRecorder) GetLinter() *gomock.Call
- func (mr *MockContainerMockRecorder) GetLogger() *gomock.Call
- func (mr *MockContainerMockRecorder) GetRegistryAuth() *gomock.Call
- func (mr *MockContainerMockRecorder) GetRegistryConfig() *gomock.Call
- func (mr *MockContainerMockRecorder) GetVulnChecker() *gomock.Call
- func (mr *MockContainerMockRecorder) Register(name, factory any) *gomock.Call
- func (mr *MockContainerMockRecorder) Start(ctx any) *gomock.Call
- func (mr *MockContainerMockRecorder) Stop(ctx any) *gomock.Call
- func (mr *MockContainerMockRecorder) Validate() *gomock.Call
- type MockDaggerCacheVolume
- type MockDaggerCacheVolumeMockRecorder
- type MockDaggerClient
- func (m *MockDaggerClient) CacheVolume(arg0 string) pipelines.DaggerCacheVolume
- func (m *MockDaggerClient) Container() pipelines.DaggerContainer
- func (m *MockDaggerClient) EXPECT() *MockDaggerClientMockRecorder
- func (m *MockDaggerClient) GetRealClient() *dagger.Client
- func (m *MockDaggerClient) Host() pipelines.DaggerHost
- type MockDaggerClientMockRecorder
- type MockDaggerContainer
- func (m *MockDaggerContainer) EXPECT() *MockDaggerContainerMockRecorder
- func (m *MockDaggerContainer) File(arg0 string) pipelines.DaggerFile
- func (m *MockDaggerContainer) From(arg0 string) pipelines.DaggerContainer
- func (m *MockDaggerContainer) WithEnvVariable(arg0, arg1 string) pipelines.DaggerContainer
- func (m *MockDaggerContainer) WithExec(arg0 []string, arg1 pipelines.DaggerContainerWithExecOpts) pipelines.DaggerContainer
- func (m *MockDaggerContainer) WithMountedCache(arg0 string, arg1 pipelines.DaggerCacheVolume) pipelines.DaggerContainer
- func (m *MockDaggerContainer) WithMountedDirectory(arg0 string, arg1 pipelines.DaggerDirectory) pipelines.DaggerContainer
- func (m *MockDaggerContainer) WithWorkdir(arg0 string) pipelines.DaggerContainer
- type MockDaggerContainerMockRecorder
- func (mr *MockDaggerContainerMockRecorder) File(arg0 any) *gomock.Call
- func (mr *MockDaggerContainerMockRecorder) From(arg0 any) *gomock.Call
- func (mr *MockDaggerContainerMockRecorder) WithEnvVariable(arg0, arg1 any) *gomock.Call
- func (mr *MockDaggerContainerMockRecorder) WithExec(arg0, arg1 any) *gomock.Call
- func (mr *MockDaggerContainerMockRecorder) WithMountedCache(arg0, arg1 any) *gomock.Call
- func (mr *MockDaggerContainerMockRecorder) WithMountedDirectory(arg0, arg1 any) *gomock.Call
- func (mr *MockDaggerContainerMockRecorder) WithWorkdir(arg0 any) *gomock.Call
- type MockDaggerDirectory
- type MockDaggerDirectoryMockRecorder
- type MockDaggerFile
- type MockDaggerFileMockRecorder
- type MockDaggerHost
- type MockDaggerHostMockRecorder
- type MockHookManager
- func (m *MockHookManager) EXPECT() *MockHookManagerMockRecorder
- func (m *MockHookManager) ExecuteHooks(ctx context.Context, stepName string, hookType interfaces.HookType) error
- func (m *MockHookManager) GetHooks(stepName string, hookType interfaces.HookType) []interfaces.HookFunc
- func (m *MockHookManager) RegisterHook(stepName string, hookType interfaces.HookType, hook interfaces.HookFunc) error
- func (m *MockHookManager) RemoveHook(stepName string, hookType interfaces.HookType, hook interfaces.HookFunc) error
- type MockHookManagerMockRecorder
- func (mr *MockHookManagerMockRecorder) ExecuteHooks(ctx, stepName, hookType any) *gomock.Call
- func (mr *MockHookManagerMockRecorder) GetHooks(stepName, hookType any) *gomock.Call
- func (mr *MockHookManagerMockRecorder) RegisterHook(stepName, hookType, hook any) *gomock.Call
- func (mr *MockHookManagerMockRecorder) RemoveHook(stepName, hookType, hook any) *gomock.Call
- type MockLinter
- type MockLinterMockRecorder
- type MockLogger
- func (m *MockLogger) Debug(msg string, fields ...any)
- func (m *MockLogger) EXPECT() *MockLoggerMockRecorder
- func (m *MockLogger) Error(msg string, fields ...any)
- func (m *MockLogger) Fatal(msg string, fields ...any)
- func (m *MockLogger) Info(msg string, fields ...any)
- func (m *MockLogger) Warn(msg string, fields ...any)
- func (m *MockLogger) WithField(key string, value any) interfaces.Logger
- func (m *MockLogger) WithFields(fields map[string]any) interfaces.Logger
- type MockLoggerMockRecorder
- func (mr *MockLoggerMockRecorder) Debug(msg any, fields ...any) *gomock.Call
- func (mr *MockLoggerMockRecorder) Error(msg any, fields ...any) *gomock.Call
- func (mr *MockLoggerMockRecorder) Fatal(msg any, fields ...any) *gomock.Call
- func (mr *MockLoggerMockRecorder) Info(msg any, fields ...any) *gomock.Call
- func (mr *MockLoggerMockRecorder) Warn(msg any, fields ...any) *gomock.Call
- func (mr *MockLoggerMockRecorder) WithField(key, value any) *gomock.Call
- func (mr *MockLoggerMockRecorder) WithFields(fields any) *gomock.Call
- type MockLoggingProvider
- type MockLoggingProviderMockRecorder
- type MockPipelineExecutor
- func (m *MockPipelineExecutor) CancelPipeline(pipelineName string) error
- func (m *MockPipelineExecutor) EXPECT() *MockPipelineExecutorMockRecorder
- func (m *MockPipelineExecutor) ExecutePipeline(ctx context.Context, pipelineName string, steps []string) error
- func (m *MockPipelineExecutor) ExecuteStep(ctx context.Context, pipelineName, stepName string) error
- func (m *MockPipelineExecutor) GetPipelineLogs(pipelineName string) ([]string, error)
- func (m *MockPipelineExecutor) GetPipelineStatus(pipelineName string) (interfaces.PipelineStatus, error)
- func (m *MockPipelineExecutor) GetStepStatus(pipelineName, stepName string) (interfaces.StepResult, error)
- type MockPipelineExecutorMockRecorder
- func (mr *MockPipelineExecutorMockRecorder) CancelPipeline(pipelineName any) *gomock.Call
- func (mr *MockPipelineExecutorMockRecorder) ExecutePipeline(ctx, pipelineName, steps any) *gomock.Call
- func (mr *MockPipelineExecutorMockRecorder) ExecuteStep(ctx, pipelineName, stepName any) *gomock.Call
- func (mr *MockPipelineExecutorMockRecorder) GetPipelineLogs(pipelineName any) *gomock.Call
- func (mr *MockPipelineExecutorMockRecorder) GetPipelineStatus(pipelineName any) *gomock.Call
- func (mr *MockPipelineExecutorMockRecorder) GetStepStatus(pipelineName, stepName any) *gomock.Call
- type MockRegistryProvider
- type MockRegistryProviderMockRecorder
- type MockRepoCloner
- type MockRepoClonerMockRecorder
- type MockSecurityProvider
- type MockSecurityProviderMockRecorder
- type MockStepExecutor
- func (m *MockStepExecutor) EXPECT() *MockStepExecutorMockRecorder
- func (m *MockStepExecutor) Execute(ctx context.Context, stepName string, config interfaces.StepConfig) error
- func (m *MockStepExecutor) GetStepLogs(stepName string) ([]string, error)
- func (m *MockStepExecutor) GetStepResult(stepName string) (interfaces.StepResult, error)
- type MockStepExecutorMockRecorder
- type MockStepHandler
- func (m *MockStepHandler) CanHandle(stepName string) bool
- func (m *MockStepHandler) EXPECT() *MockStepHandlerMockRecorder
- func (m *MockStepHandler) Execute(ctx context.Context, stepName string, config interfaces.StepConfig) error
- func (m *MockStepHandler) GetStepInfo(stepName string) interfaces.StepConfig
- func (m *MockStepHandler) Validate(stepName string, config interfaces.StepConfig) error
- type MockStepHandlerMockRecorder
- func (mr *MockStepHandlerMockRecorder) CanHandle(stepName any) *gomock.Call
- func (mr *MockStepHandlerMockRecorder) Execute(ctx, stepName, config any) *gomock.Call
- func (mr *MockStepHandlerMockRecorder) GetStepInfo(stepName any) *gomock.Call
- func (mr *MockStepHandlerMockRecorder) Validate(stepName, config any) *gomock.Call
- type MockStepRegistry
- func (m *MockStepRegistry) EXPECT() *MockStepRegistryMockRecorder
- func (m *MockStepRegistry) ExecuteStep(ctx context.Context, stepName string) error
- func (m *MockStepRegistry) GetExecutionOrder() ([]string, error)
- func (m *MockStepRegistry) GetStepConfig(stepName string) (interfaces.StepConfig, error)
- func (m *MockStepRegistry) GetStepHandler(stepName string) (interfaces.StepHandler, error)
- func (m *MockStepRegistry) ListSteps() []string
- func (m *MockStepRegistry) RegisterStep(stepName string, handler interfaces.StepHandler) error
- func (m *MockStepRegistry) ValidateStep(stepName string) error
- type MockStepRegistryMockRecorder
- func (mr *MockStepRegistryMockRecorder) ExecuteStep(ctx, stepName any) *gomock.Call
- func (mr *MockStepRegistryMockRecorder) GetExecutionOrder() *gomock.Call
- func (mr *MockStepRegistryMockRecorder) GetStepConfig(stepName any) *gomock.Call
- func (mr *MockStepRegistryMockRecorder) GetStepHandler(stepName any) *gomock.Call
- func (mr *MockStepRegistryMockRecorder) ListSteps() *gomock.Call
- func (mr *MockStepRegistryMockRecorder) RegisterStep(stepName, handler any) *gomock.Call
- func (mr *MockStepRegistryMockRecorder) ValidateStep(stepName any) *gomock.Call
- type MockTestable
- type MockTestableMockRecorder
- type MockVulnChecker
- type MockVulnCheckerMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockCloner ¶
type MockCloner struct {
// contains filtered or unexported fields
}
MockCloner is a mock of Cloner interface.
func NewMockCloner ¶
func NewMockCloner(ctrl *gomock.Controller) *MockCloner
NewMockCloner creates a new mock instance.
func (*MockCloner) Clone ¶
func (m *MockCloner) Clone(ctx context.Context, client *dagger.Client, opts shared.GitCloneOpts) (*dagger.Directory, error)
Clone mocks base method.
func (*MockCloner) EXPECT ¶
func (m *MockCloner) EXPECT() *MockClonerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockClonerMockRecorder ¶
type MockClonerMockRecorder struct {
// contains filtered or unexported fields
}
MockClonerMockRecorder is the mock recorder for MockCloner.
type MockConfiguration ¶
type MockConfiguration struct {
// contains filtered or unexported fields
}
MockConfiguration is a mock of Configuration interface.
func NewMockConfiguration ¶
func NewMockConfiguration(ctrl *gomock.Controller) *MockConfiguration
NewMockConfiguration creates a new mock instance.
func (*MockConfiguration) All ¶
func (m *MockConfiguration) All() map[string]any
All mocks base method.
func (*MockConfiguration) EXPECT ¶
func (m *MockConfiguration) EXPECT() *MockConfigurationMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockConfiguration) Environment ¶
func (m *MockConfiguration) Environment() string
Environment mocks base method.
func (*MockConfiguration) Get ¶
func (m *MockConfiguration) Get(key string) any
Get mocks base method.
func (*MockConfiguration) GetBool ¶
func (m *MockConfiguration) GetBool(key string) bool
GetBool mocks base method.
func (*MockConfiguration) GetConfigSummary ¶
func (m *MockConfiguration) GetConfigSummary() string
GetConfigSummary mocks base method.
func (*MockConfiguration) GetDuration ¶
func (m *MockConfiguration) GetDuration(key string) time.Duration
GetDuration mocks base method.
func (*MockConfiguration) GetFloat ¶
func (m *MockConfiguration) GetFloat(key string) float64
GetFloat mocks base method.
func (*MockConfiguration) GetInt ¶
func (m *MockConfiguration) GetInt(key string) int
GetInt mocks base method.
func (*MockConfiguration) GetString ¶
func (m *MockConfiguration) GetString(key string) string
GetString mocks base method.
func (*MockConfiguration) Has ¶
func (m *MockConfiguration) Has(key string) bool
Has mocks base method.
func (*MockConfiguration) LoadWithDefaults ¶
func (m *MockConfiguration) LoadWithDefaults(defaults map[string]any) error
LoadWithDefaults mocks base method.
func (*MockConfiguration) Logging ¶
func (m *MockConfiguration) Logging() interfaces.LoggingConfig
Logging mocks base method.
func (*MockConfiguration) Pipeline ¶
func (m *MockConfiguration) Pipeline() interfaces.PipelineConfig
Pipeline mocks base method.
func (*MockConfiguration) Registry ¶
func (m *MockConfiguration) Registry() interfaces.RegistryConfig
Registry mocks base method.
func (*MockConfiguration) Security ¶
func (m *MockConfiguration) Security() interfaces.SecurityConfig
Security mocks base method.
func (*MockConfiguration) Set ¶
func (m *MockConfiguration) Set(key string, value any)
Set mocks base method.
func (*MockConfiguration) Validate ¶
func (m *MockConfiguration) Validate() error
Validate mocks base method.
type MockConfigurationMockRecorder ¶
type MockConfigurationMockRecorder struct {
// contains filtered or unexported fields
}
MockConfigurationMockRecorder is the mock recorder for MockConfiguration.
func (*MockConfigurationMockRecorder) All ¶
func (mr *MockConfigurationMockRecorder) All() *gomock.Call
All indicates an expected call of All.
func (*MockConfigurationMockRecorder) Environment ¶
func (mr *MockConfigurationMockRecorder) Environment() *gomock.Call
Environment indicates an expected call of Environment.
func (*MockConfigurationMockRecorder) Get ¶
func (mr *MockConfigurationMockRecorder) Get(key any) *gomock.Call
Get indicates an expected call of Get.
func (*MockConfigurationMockRecorder) GetBool ¶
func (mr *MockConfigurationMockRecorder) GetBool(key any) *gomock.Call
GetBool indicates an expected call of GetBool.
func (*MockConfigurationMockRecorder) GetConfigSummary ¶
func (mr *MockConfigurationMockRecorder) GetConfigSummary() *gomock.Call
GetConfigSummary indicates an expected call of GetConfigSummary.
func (*MockConfigurationMockRecorder) GetDuration ¶
func (mr *MockConfigurationMockRecorder) GetDuration(key any) *gomock.Call
GetDuration indicates an expected call of GetDuration.
func (*MockConfigurationMockRecorder) GetFloat ¶
func (mr *MockConfigurationMockRecorder) GetFloat(key any) *gomock.Call
GetFloat indicates an expected call of GetFloat.
func (*MockConfigurationMockRecorder) GetInt ¶
func (mr *MockConfigurationMockRecorder) GetInt(key any) *gomock.Call
GetInt indicates an expected call of GetInt.
func (*MockConfigurationMockRecorder) GetString ¶
func (mr *MockConfigurationMockRecorder) GetString(key any) *gomock.Call
GetString indicates an expected call of GetString.
func (*MockConfigurationMockRecorder) Has ¶
func (mr *MockConfigurationMockRecorder) Has(key any) *gomock.Call
Has indicates an expected call of Has.
func (*MockConfigurationMockRecorder) Load ¶
func (mr *MockConfigurationMockRecorder) Load() *gomock.Call
Load indicates an expected call of Load.
func (*MockConfigurationMockRecorder) LoadWithDefaults ¶
func (mr *MockConfigurationMockRecorder) LoadWithDefaults(defaults any) *gomock.Call
LoadWithDefaults indicates an expected call of LoadWithDefaults.
func (*MockConfigurationMockRecorder) Logging ¶
func (mr *MockConfigurationMockRecorder) Logging() *gomock.Call
Logging indicates an expected call of Logging.
func (*MockConfigurationMockRecorder) Pipeline ¶
func (mr *MockConfigurationMockRecorder) Pipeline() *gomock.Call
Pipeline indicates an expected call of Pipeline.
func (*MockConfigurationMockRecorder) Registry ¶
func (mr *MockConfigurationMockRecorder) Registry() *gomock.Call
Registry indicates an expected call of Registry.
func (*MockConfigurationMockRecorder) Security ¶
func (mr *MockConfigurationMockRecorder) Security() *gomock.Call
Security indicates an expected call of Security.
func (*MockConfigurationMockRecorder) Set ¶
func (mr *MockConfigurationMockRecorder) Set(key, value any) *gomock.Call
Set indicates an expected call of Set.
func (*MockConfigurationMockRecorder) Validate ¶
func (mr *MockConfigurationMockRecorder) Validate() *gomock.Call
Validate indicates an expected call of Validate.
type MockContainer ¶
type MockContainer struct {
// contains filtered or unexported fields
}
MockContainer is a mock of Container interface.
func NewMockContainer ¶
func NewMockContainer(ctrl *gomock.Controller) *MockContainer
NewMockContainer creates a new mock instance.
func (*MockContainer) EXPECT ¶
func (m *MockContainer) EXPECT() *MockContainerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockContainer) Get ¶
func (m *MockContainer) Get(name string) (any, error)
Get mocks base method.
func (*MockContainer) GetLinter ¶
func (m *MockContainer) GetLinter() (interfaces.Linter, error)
GetLinter mocks base method.
func (*MockContainer) GetLogger ¶
func (m *MockContainer) GetLogger() (interfaces.Logger, error)
GetLogger mocks base method.
func (*MockContainer) GetRegistryAuth ¶
func (m *MockContainer) GetRegistryAuth() (string, string, error)
GetRegistryAuth mocks base method.
func (*MockContainer) GetRegistryConfig ¶
func (m *MockContainer) GetRegistryConfig() (interfaces.RegistryConfig, error)
GetRegistryConfig mocks base method.
func (*MockContainer) GetVulnChecker ¶
func (m *MockContainer) GetVulnChecker() (interfaces.VulnChecker, error)
GetVulnChecker mocks base method.
func (*MockContainer) Register ¶
func (m *MockContainer) Register(name string, factory func() (any, error))
Register mocks base method.
func (*MockContainer) Start ¶
func (m *MockContainer) Start(ctx context.Context) error
Start mocks base method.
func (*MockContainer) Stop ¶
func (m *MockContainer) Stop(ctx context.Context) error
Stop mocks base method.
func (*MockContainer) Validate ¶
func (m *MockContainer) Validate() error
Validate mocks base method.
type MockContainerMockRecorder ¶
type MockContainerMockRecorder struct {
// contains filtered or unexported fields
}
MockContainerMockRecorder is the mock recorder for MockContainer.
func (*MockContainerMockRecorder) Get ¶
func (mr *MockContainerMockRecorder) Get(name any) *gomock.Call
Get indicates an expected call of Get.
func (*MockContainerMockRecorder) GetLinter ¶
func (mr *MockContainerMockRecorder) GetLinter() *gomock.Call
GetLinter indicates an expected call of GetLinter.
func (*MockContainerMockRecorder) GetLogger ¶
func (mr *MockContainerMockRecorder) GetLogger() *gomock.Call
GetLogger indicates an expected call of GetLogger.
func (*MockContainerMockRecorder) GetRegistryAuth ¶
func (mr *MockContainerMockRecorder) GetRegistryAuth() *gomock.Call
GetRegistryAuth indicates an expected call of GetRegistryAuth.
func (*MockContainerMockRecorder) GetRegistryConfig ¶
func (mr *MockContainerMockRecorder) GetRegistryConfig() *gomock.Call
GetRegistryConfig indicates an expected call of GetRegistryConfig.
func (*MockContainerMockRecorder) GetVulnChecker ¶
func (mr *MockContainerMockRecorder) GetVulnChecker() *gomock.Call
GetVulnChecker indicates an expected call of GetVulnChecker.
func (*MockContainerMockRecorder) Register ¶
func (mr *MockContainerMockRecorder) Register(name, factory any) *gomock.Call
Register indicates an expected call of Register.
func (*MockContainerMockRecorder) Start ¶
func (mr *MockContainerMockRecorder) Start(ctx any) *gomock.Call
Start indicates an expected call of Start.
func (*MockContainerMockRecorder) Stop ¶
func (mr *MockContainerMockRecorder) Stop(ctx any) *gomock.Call
Stop indicates an expected call of Stop.
func (*MockContainerMockRecorder) Validate ¶
func (mr *MockContainerMockRecorder) Validate() *gomock.Call
Validate indicates an expected call of Validate.
type MockDaggerCacheVolume ¶
type MockDaggerCacheVolume struct {
// contains filtered or unexported fields
}
MockDaggerCacheVolume is a mock of DaggerCacheVolume interface.
func NewMockDaggerCacheVolume ¶
func NewMockDaggerCacheVolume(ctrl *gomock.Controller) *MockDaggerCacheVolume
NewMockDaggerCacheVolume creates a new mock instance.
func (*MockDaggerCacheVolume) EXPECT ¶
func (m *MockDaggerCacheVolume) EXPECT() *MockDaggerCacheVolumeMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockDaggerCacheVolumeMockRecorder ¶
type MockDaggerCacheVolumeMockRecorder struct {
// contains filtered or unexported fields
}
MockDaggerCacheVolumeMockRecorder is the mock recorder for MockDaggerCacheVolume.
type MockDaggerClient ¶
type MockDaggerClient struct {
// contains filtered or unexported fields
}
MockDaggerClient is a mock of DaggerClient interface.
func NewMockDaggerClient ¶
func NewMockDaggerClient(ctrl *gomock.Controller) *MockDaggerClient
NewMockDaggerClient creates a new mock instance.
func (*MockDaggerClient) CacheVolume ¶
func (m *MockDaggerClient) CacheVolume(arg0 string) pipelines.DaggerCacheVolume
CacheVolume mocks base method.
func (*MockDaggerClient) Container ¶
func (m *MockDaggerClient) Container() pipelines.DaggerContainer
Container mocks base method.
func (*MockDaggerClient) EXPECT ¶
func (m *MockDaggerClient) EXPECT() *MockDaggerClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDaggerClient) GetRealClient ¶
func (m *MockDaggerClient) GetRealClient() *dagger.Client
GetRealClient mocks base method.
func (*MockDaggerClient) Host ¶
func (m *MockDaggerClient) Host() pipelines.DaggerHost
Host mocks base method.
type MockDaggerClientMockRecorder ¶
type MockDaggerClientMockRecorder struct {
// contains filtered or unexported fields
}
MockDaggerClientMockRecorder is the mock recorder for MockDaggerClient.
func (*MockDaggerClientMockRecorder) CacheVolume ¶
func (mr *MockDaggerClientMockRecorder) CacheVolume(arg0 any) *gomock.Call
CacheVolume indicates an expected call of CacheVolume.
func (*MockDaggerClientMockRecorder) Container ¶
func (mr *MockDaggerClientMockRecorder) Container() *gomock.Call
Container indicates an expected call of Container.
func (*MockDaggerClientMockRecorder) GetRealClient ¶
func (mr *MockDaggerClientMockRecorder) GetRealClient() *gomock.Call
GetRealClient indicates an expected call of GetRealClient.
func (*MockDaggerClientMockRecorder) Host ¶
func (mr *MockDaggerClientMockRecorder) Host() *gomock.Call
Host indicates an expected call of Host.
type MockDaggerContainer ¶
type MockDaggerContainer struct {
// contains filtered or unexported fields
}
MockDaggerContainer is a mock of DaggerContainer interface.
func NewMockDaggerContainer ¶
func NewMockDaggerContainer(ctrl *gomock.Controller) *MockDaggerContainer
NewMockDaggerContainer creates a new mock instance.
func (*MockDaggerContainer) EXPECT ¶
func (m *MockDaggerContainer) EXPECT() *MockDaggerContainerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDaggerContainer) File ¶
func (m *MockDaggerContainer) File(arg0 string) pipelines.DaggerFile
File mocks base method.
func (*MockDaggerContainer) From ¶
func (m *MockDaggerContainer) From(arg0 string) pipelines.DaggerContainer
From mocks base method.
func (*MockDaggerContainer) WithEnvVariable ¶
func (m *MockDaggerContainer) WithEnvVariable(arg0, arg1 string) pipelines.DaggerContainer
WithEnvVariable mocks base method.
func (*MockDaggerContainer) WithExec ¶
func (m *MockDaggerContainer) WithExec(arg0 []string, arg1 pipelines.DaggerContainerWithExecOpts) pipelines.DaggerContainer
WithExec mocks base method.
func (*MockDaggerContainer) WithMountedCache ¶
func (m *MockDaggerContainer) WithMountedCache(arg0 string, arg1 pipelines.DaggerCacheVolume) pipelines.DaggerContainer
WithMountedCache mocks base method.
func (*MockDaggerContainer) WithMountedDirectory ¶
func (m *MockDaggerContainer) WithMountedDirectory(arg0 string, arg1 pipelines.DaggerDirectory) pipelines.DaggerContainer
WithMountedDirectory mocks base method.
func (*MockDaggerContainer) WithWorkdir ¶
func (m *MockDaggerContainer) WithWorkdir(arg0 string) pipelines.DaggerContainer
WithWorkdir mocks base method.
type MockDaggerContainerMockRecorder ¶
type MockDaggerContainerMockRecorder struct {
// contains filtered or unexported fields
}
MockDaggerContainerMockRecorder is the mock recorder for MockDaggerContainer.
func (*MockDaggerContainerMockRecorder) File ¶
func (mr *MockDaggerContainerMockRecorder) File(arg0 any) *gomock.Call
File indicates an expected call of File.
func (*MockDaggerContainerMockRecorder) From ¶
func (mr *MockDaggerContainerMockRecorder) From(arg0 any) *gomock.Call
From indicates an expected call of From.
func (*MockDaggerContainerMockRecorder) WithEnvVariable ¶
func (mr *MockDaggerContainerMockRecorder) WithEnvVariable(arg0, arg1 any) *gomock.Call
WithEnvVariable indicates an expected call of WithEnvVariable.
func (*MockDaggerContainerMockRecorder) WithExec ¶
func (mr *MockDaggerContainerMockRecorder) WithExec(arg0, arg1 any) *gomock.Call
WithExec indicates an expected call of WithExec.
func (*MockDaggerContainerMockRecorder) WithMountedCache ¶
func (mr *MockDaggerContainerMockRecorder) WithMountedCache(arg0, arg1 any) *gomock.Call
WithMountedCache indicates an expected call of WithMountedCache.
func (*MockDaggerContainerMockRecorder) WithMountedDirectory ¶
func (mr *MockDaggerContainerMockRecorder) WithMountedDirectory(arg0, arg1 any) *gomock.Call
WithMountedDirectory indicates an expected call of WithMountedDirectory.
func (*MockDaggerContainerMockRecorder) WithWorkdir ¶
func (mr *MockDaggerContainerMockRecorder) WithWorkdir(arg0 any) *gomock.Call
WithWorkdir indicates an expected call of WithWorkdir.
type MockDaggerDirectory ¶
type MockDaggerDirectory struct {
// contains filtered or unexported fields
}
MockDaggerDirectory is a mock of DaggerDirectory interface.
func NewMockDaggerDirectory ¶
func NewMockDaggerDirectory(ctrl *gomock.Controller) *MockDaggerDirectory
NewMockDaggerDirectory creates a new mock instance.
func (*MockDaggerDirectory) EXPECT ¶
func (m *MockDaggerDirectory) EXPECT() *MockDaggerDirectoryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockDaggerDirectory) GetRealDirectory ¶
func (m *MockDaggerDirectory) GetRealDirectory() *dagger.Directory
GetRealDirectory mocks base method.
type MockDaggerDirectoryMockRecorder ¶
type MockDaggerDirectoryMockRecorder struct {
// contains filtered or unexported fields
}
MockDaggerDirectoryMockRecorder is the mock recorder for MockDaggerDirectory.
func (*MockDaggerDirectoryMockRecorder) GetRealDirectory ¶
func (mr *MockDaggerDirectoryMockRecorder) GetRealDirectory() *gomock.Call
GetRealDirectory indicates an expected call of GetRealDirectory.
type MockDaggerFile ¶
type MockDaggerFile struct {
// contains filtered or unexported fields
}
MockDaggerFile is a mock of DaggerFile interface.
func NewMockDaggerFile ¶
func NewMockDaggerFile(ctrl *gomock.Controller) *MockDaggerFile
NewMockDaggerFile creates a new mock instance.
func (*MockDaggerFile) Contents ¶
func (m *MockDaggerFile) Contents(arg0 context.Context) (string, error)
Contents mocks base method.
func (*MockDaggerFile) EXPECT ¶
func (m *MockDaggerFile) EXPECT() *MockDaggerFileMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockDaggerFileMockRecorder ¶
type MockDaggerFileMockRecorder struct {
// contains filtered or unexported fields
}
MockDaggerFileMockRecorder is the mock recorder for MockDaggerFile.
type MockDaggerHost ¶
type MockDaggerHost struct {
// contains filtered or unexported fields
}
MockDaggerHost is a mock of DaggerHost interface.
func NewMockDaggerHost ¶
func NewMockDaggerHost(ctrl *gomock.Controller) *MockDaggerHost
NewMockDaggerHost creates a new mock instance.
func (*MockDaggerHost) Directory ¶
func (m *MockDaggerHost) Directory(arg0 string, arg1 pipelines.DaggerHostDirectoryOpts) pipelines.DaggerDirectory
Directory mocks base method.
func (*MockDaggerHost) EXPECT ¶
func (m *MockDaggerHost) EXPECT() *MockDaggerHostMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockDaggerHostMockRecorder ¶
type MockDaggerHostMockRecorder struct {
// contains filtered or unexported fields
}
MockDaggerHostMockRecorder is the mock recorder for MockDaggerHost.
type MockHookManager ¶
type MockHookManager struct {
// contains filtered or unexported fields
}
MockHookManager is a mock of HookManager interface.
func NewMockHookManager ¶
func NewMockHookManager(ctrl *gomock.Controller) *MockHookManager
NewMockHookManager creates a new mock instance.
func (*MockHookManager) EXPECT ¶
func (m *MockHookManager) EXPECT() *MockHookManagerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockHookManager) ExecuteHooks ¶
func (m *MockHookManager) ExecuteHooks(ctx context.Context, stepName string, hookType interfaces.HookType) error
ExecuteHooks mocks base method.
func (*MockHookManager) GetHooks ¶
func (m *MockHookManager) GetHooks(stepName string, hookType interfaces.HookType) []interfaces.HookFunc
GetHooks mocks base method.
func (*MockHookManager) RegisterHook ¶
func (m *MockHookManager) RegisterHook(stepName string, hookType interfaces.HookType, hook interfaces.HookFunc) error
RegisterHook mocks base method.
func (*MockHookManager) RemoveHook ¶
func (m *MockHookManager) RemoveHook(stepName string, hookType interfaces.HookType, hook interfaces.HookFunc) error
RemoveHook mocks base method.
type MockHookManagerMockRecorder ¶
type MockHookManagerMockRecorder struct {
// contains filtered or unexported fields
}
MockHookManagerMockRecorder is the mock recorder for MockHookManager.
func (*MockHookManagerMockRecorder) ExecuteHooks ¶
func (mr *MockHookManagerMockRecorder) ExecuteHooks(ctx, stepName, hookType any) *gomock.Call
ExecuteHooks indicates an expected call of ExecuteHooks.
func (*MockHookManagerMockRecorder) GetHooks ¶
func (mr *MockHookManagerMockRecorder) GetHooks(stepName, hookType any) *gomock.Call
GetHooks indicates an expected call of GetHooks.
func (*MockHookManagerMockRecorder) RegisterHook ¶
func (mr *MockHookManagerMockRecorder) RegisterHook(stepName, hookType, hook any) *gomock.Call
RegisterHook indicates an expected call of RegisterHook.
func (*MockHookManagerMockRecorder) RemoveHook ¶
func (mr *MockHookManagerMockRecorder) RemoveHook(stepName, hookType, hook any) *gomock.Call
RemoveHook indicates an expected call of RemoveHook.
type MockLinter ¶
type MockLinter struct {
// contains filtered or unexported fields
}
MockLinter is a mock of Linter interface.
func NewMockLinter ¶
func NewMockLinter(ctrl *gomock.Controller) *MockLinter
NewMockLinter creates a new mock instance.
func (*MockLinter) EXPECT ¶
func (m *MockLinter) EXPECT() *MockLinterMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockLinterMockRecorder ¶
type MockLinterMockRecorder struct {
// contains filtered or unexported fields
}
MockLinterMockRecorder is the mock recorder for MockLinter.
type MockLogger ¶
type MockLogger struct {
// contains filtered or unexported fields
}
MockLogger is a mock of Logger interface.
func NewMockLogger ¶
func NewMockLogger(ctrl *gomock.Controller) *MockLogger
NewMockLogger creates a new mock instance.
func (*MockLogger) Debug ¶
func (m *MockLogger) Debug(msg string, fields ...any)
Debug mocks base method.
func (*MockLogger) EXPECT ¶
func (m *MockLogger) EXPECT() *MockLoggerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockLogger) Error ¶
func (m *MockLogger) Error(msg string, fields ...any)
Error mocks base method.
func (*MockLogger) Fatal ¶
func (m *MockLogger) Fatal(msg string, fields ...any)
Fatal mocks base method.
func (*MockLogger) Info ¶
func (m *MockLogger) Info(msg string, fields ...any)
Info mocks base method.
func (*MockLogger) Warn ¶
func (m *MockLogger) Warn(msg string, fields ...any)
Warn mocks base method.
func (*MockLogger) WithField ¶
func (m *MockLogger) WithField(key string, value any) interfaces.Logger
WithField mocks base method.
func (*MockLogger) WithFields ¶
func (m *MockLogger) WithFields(fields map[string]any) interfaces.Logger
WithFields mocks base method.
type MockLoggerMockRecorder ¶
type MockLoggerMockRecorder struct {
// contains filtered or unexported fields
}
MockLoggerMockRecorder is the mock recorder for MockLogger.
func (*MockLoggerMockRecorder) Debug ¶
func (mr *MockLoggerMockRecorder) Debug(msg any, fields ...any) *gomock.Call
Debug indicates an expected call of Debug.
func (*MockLoggerMockRecorder) Error ¶
func (mr *MockLoggerMockRecorder) Error(msg any, fields ...any) *gomock.Call
Error indicates an expected call of Error.
func (*MockLoggerMockRecorder) Fatal ¶
func (mr *MockLoggerMockRecorder) Fatal(msg any, fields ...any) *gomock.Call
Fatal indicates an expected call of Fatal.
func (*MockLoggerMockRecorder) Info ¶
func (mr *MockLoggerMockRecorder) Info(msg any, fields ...any) *gomock.Call
Info indicates an expected call of Info.
func (*MockLoggerMockRecorder) Warn ¶
func (mr *MockLoggerMockRecorder) Warn(msg any, fields ...any) *gomock.Call
Warn indicates an expected call of Warn.
func (*MockLoggerMockRecorder) WithField ¶
func (mr *MockLoggerMockRecorder) WithField(key, value any) *gomock.Call
WithField indicates an expected call of WithField.
func (*MockLoggerMockRecorder) WithFields ¶
func (mr *MockLoggerMockRecorder) WithFields(fields any) *gomock.Call
WithFields indicates an expected call of WithFields.
type MockLoggingProvider ¶
type MockLoggingProvider struct {
// contains filtered or unexported fields
}
MockLoggingProvider is a mock of LoggingProvider interface.
func NewMockLoggingProvider ¶
func NewMockLoggingProvider(ctrl *gomock.Controller) *MockLoggingProvider
NewMockLoggingProvider creates a new mock instance.
func (*MockLoggingProvider) EXPECT ¶
func (m *MockLoggingProvider) EXPECT() *MockLoggingProviderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockLoggingProvider) GetLogger ¶
func (m *MockLoggingProvider) GetLogger() (interfaces.Logger, error)
GetLogger mocks base method.
type MockLoggingProviderMockRecorder ¶
type MockLoggingProviderMockRecorder struct {
// contains filtered or unexported fields
}
MockLoggingProviderMockRecorder is the mock recorder for MockLoggingProvider.
func (*MockLoggingProviderMockRecorder) GetLogger ¶
func (mr *MockLoggingProviderMockRecorder) GetLogger() *gomock.Call
GetLogger indicates an expected call of GetLogger.
type MockPipelineExecutor ¶
type MockPipelineExecutor struct {
// contains filtered or unexported fields
}
MockPipelineExecutor is a mock of PipelineExecutor interface.
func NewMockPipelineExecutor ¶
func NewMockPipelineExecutor(ctrl *gomock.Controller) *MockPipelineExecutor
NewMockPipelineExecutor creates a new mock instance.
func (*MockPipelineExecutor) CancelPipeline ¶
func (m *MockPipelineExecutor) CancelPipeline(pipelineName string) error
CancelPipeline mocks base method.
func (*MockPipelineExecutor) EXPECT ¶
func (m *MockPipelineExecutor) EXPECT() *MockPipelineExecutorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockPipelineExecutor) ExecutePipeline ¶
func (m *MockPipelineExecutor) ExecutePipeline(ctx context.Context, pipelineName string, steps []string) error
ExecutePipeline mocks base method.
func (*MockPipelineExecutor) ExecuteStep ¶
func (m *MockPipelineExecutor) ExecuteStep(ctx context.Context, pipelineName, stepName string) error
ExecuteStep mocks base method.
func (*MockPipelineExecutor) GetPipelineLogs ¶
func (m *MockPipelineExecutor) GetPipelineLogs(pipelineName string) ([]string, error)
GetPipelineLogs mocks base method.
func (*MockPipelineExecutor) GetPipelineStatus ¶
func (m *MockPipelineExecutor) GetPipelineStatus(pipelineName string) (interfaces.PipelineStatus, error)
GetPipelineStatus mocks base method.
func (*MockPipelineExecutor) GetStepStatus ¶
func (m *MockPipelineExecutor) GetStepStatus(pipelineName, stepName string) (interfaces.StepResult, error)
GetStepStatus mocks base method.
type MockPipelineExecutorMockRecorder ¶
type MockPipelineExecutorMockRecorder struct {
// contains filtered or unexported fields
}
MockPipelineExecutorMockRecorder is the mock recorder for MockPipelineExecutor.
func (*MockPipelineExecutorMockRecorder) CancelPipeline ¶
func (mr *MockPipelineExecutorMockRecorder) CancelPipeline(pipelineName any) *gomock.Call
CancelPipeline indicates an expected call of CancelPipeline.
func (*MockPipelineExecutorMockRecorder) ExecutePipeline ¶
func (mr *MockPipelineExecutorMockRecorder) ExecutePipeline(ctx, pipelineName, steps any) *gomock.Call
ExecutePipeline indicates an expected call of ExecutePipeline.
func (*MockPipelineExecutorMockRecorder) ExecuteStep ¶
func (mr *MockPipelineExecutorMockRecorder) ExecuteStep(ctx, pipelineName, stepName any) *gomock.Call
ExecuteStep indicates an expected call of ExecuteStep.
func (*MockPipelineExecutorMockRecorder) GetPipelineLogs ¶
func (mr *MockPipelineExecutorMockRecorder) GetPipelineLogs(pipelineName any) *gomock.Call
GetPipelineLogs indicates an expected call of GetPipelineLogs.
func (*MockPipelineExecutorMockRecorder) GetPipelineStatus ¶
func (mr *MockPipelineExecutorMockRecorder) GetPipelineStatus(pipelineName any) *gomock.Call
GetPipelineStatus indicates an expected call of GetPipelineStatus.
func (*MockPipelineExecutorMockRecorder) GetStepStatus ¶
func (mr *MockPipelineExecutorMockRecorder) GetStepStatus(pipelineName, stepName any) *gomock.Call
GetStepStatus indicates an expected call of GetStepStatus.
type MockRegistryProvider ¶
type MockRegistryProvider struct {
// contains filtered or unexported fields
}
MockRegistryProvider is a mock of RegistryProvider interface.
func NewMockRegistryProvider ¶
func NewMockRegistryProvider(ctrl *gomock.Controller) *MockRegistryProvider
NewMockRegistryProvider creates a new mock instance.
func (*MockRegistryProvider) EXPECT ¶
func (m *MockRegistryProvider) EXPECT() *MockRegistryProviderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockRegistryProvider) GetRegistryAuth ¶
func (m *MockRegistryProvider) GetRegistryAuth() (string, string, error)
GetRegistryAuth mocks base method.
func (*MockRegistryProvider) GetRegistryConfig ¶
func (m *MockRegistryProvider) GetRegistryConfig() (interfaces.RegistryConfig, error)
GetRegistryConfig mocks base method.
type MockRegistryProviderMockRecorder ¶
type MockRegistryProviderMockRecorder struct {
// contains filtered or unexported fields
}
MockRegistryProviderMockRecorder is the mock recorder for MockRegistryProvider.
func (*MockRegistryProviderMockRecorder) GetRegistryAuth ¶
func (mr *MockRegistryProviderMockRecorder) GetRegistryAuth() *gomock.Call
GetRegistryAuth indicates an expected call of GetRegistryAuth.
func (*MockRegistryProviderMockRecorder) GetRegistryConfig ¶
func (mr *MockRegistryProviderMockRecorder) GetRegistryConfig() *gomock.Call
GetRegistryConfig indicates an expected call of GetRegistryConfig.
type MockRepoCloner ¶
type MockRepoCloner struct {
// contains filtered or unexported fields
}
MockRepoCloner is a mock of RepoCloner interface.
func NewMockRepoCloner ¶
func NewMockRepoCloner(ctrl *gomock.Controller) *MockRepoCloner
NewMockRepoCloner creates a new mock instance.
func (*MockRepoCloner) Clone ¶
func (m *MockRepoCloner) Clone(ctx context.Context, client *dagger.Client, opts shared.GitCloneOpts) (*dagger.Directory, error)
Clone mocks base method.
func (*MockRepoCloner) EXPECT ¶
func (m *MockRepoCloner) EXPECT() *MockRepoClonerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockRepoClonerMockRecorder ¶
type MockRepoClonerMockRecorder struct {
// contains filtered or unexported fields
}
MockRepoClonerMockRecorder is the mock recorder for MockRepoCloner.
type MockSecurityProvider ¶
type MockSecurityProvider struct {
// contains filtered or unexported fields
}
MockSecurityProvider is a mock of SecurityProvider interface.
func NewMockSecurityProvider ¶
func NewMockSecurityProvider(ctrl *gomock.Controller) *MockSecurityProvider
NewMockSecurityProvider creates a new mock instance.
func (*MockSecurityProvider) EXPECT ¶
func (m *MockSecurityProvider) EXPECT() *MockSecurityProviderMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockSecurityProvider) GetLinter ¶
func (m *MockSecurityProvider) GetLinter() (interfaces.Linter, error)
GetLinter mocks base method.
func (*MockSecurityProvider) GetVulnChecker ¶
func (m *MockSecurityProvider) GetVulnChecker() (interfaces.VulnChecker, error)
GetVulnChecker mocks base method.
type MockSecurityProviderMockRecorder ¶
type MockSecurityProviderMockRecorder struct {
// contains filtered or unexported fields
}
MockSecurityProviderMockRecorder is the mock recorder for MockSecurityProvider.
func (*MockSecurityProviderMockRecorder) GetLinter ¶
func (mr *MockSecurityProviderMockRecorder) GetLinter() *gomock.Call
GetLinter indicates an expected call of GetLinter.
func (*MockSecurityProviderMockRecorder) GetVulnChecker ¶
func (mr *MockSecurityProviderMockRecorder) GetVulnChecker() *gomock.Call
GetVulnChecker indicates an expected call of GetVulnChecker.
type MockStepExecutor ¶
type MockStepExecutor struct {
// contains filtered or unexported fields
}
MockStepExecutor is a mock of StepExecutor interface.
func NewMockStepExecutor ¶
func NewMockStepExecutor(ctrl *gomock.Controller) *MockStepExecutor
NewMockStepExecutor creates a new mock instance.
func (*MockStepExecutor) EXPECT ¶
func (m *MockStepExecutor) EXPECT() *MockStepExecutorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockStepExecutor) Execute ¶
func (m *MockStepExecutor) Execute(ctx context.Context, stepName string, config interfaces.StepConfig) error
Execute mocks base method.
func (*MockStepExecutor) GetStepLogs ¶
func (m *MockStepExecutor) GetStepLogs(stepName string) ([]string, error)
GetStepLogs mocks base method.
func (*MockStepExecutor) GetStepResult ¶
func (m *MockStepExecutor) GetStepResult(stepName string) (interfaces.StepResult, error)
GetStepResult mocks base method.
type MockStepExecutorMockRecorder ¶
type MockStepExecutorMockRecorder struct {
// contains filtered or unexported fields
}
MockStepExecutorMockRecorder is the mock recorder for MockStepExecutor.
func (*MockStepExecutorMockRecorder) Execute ¶
func (mr *MockStepExecutorMockRecorder) Execute(ctx, stepName, config any) *gomock.Call
Execute indicates an expected call of Execute.
func (*MockStepExecutorMockRecorder) GetStepLogs ¶
func (mr *MockStepExecutorMockRecorder) GetStepLogs(stepName any) *gomock.Call
GetStepLogs indicates an expected call of GetStepLogs.
func (*MockStepExecutorMockRecorder) GetStepResult ¶
func (mr *MockStepExecutorMockRecorder) GetStepResult(stepName any) *gomock.Call
GetStepResult indicates an expected call of GetStepResult.
type MockStepHandler ¶
type MockStepHandler struct {
// contains filtered or unexported fields
}
MockStepHandler is a mock of StepHandler interface.
func NewMockStepHandler ¶
func NewMockStepHandler(ctrl *gomock.Controller) *MockStepHandler
NewMockStepHandler creates a new mock instance.
func (*MockStepHandler) CanHandle ¶
func (m *MockStepHandler) CanHandle(stepName string) bool
CanHandle mocks base method.
func (*MockStepHandler) EXPECT ¶
func (m *MockStepHandler) EXPECT() *MockStepHandlerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockStepHandler) Execute ¶
func (m *MockStepHandler) Execute(ctx context.Context, stepName string, config interfaces.StepConfig) error
Execute mocks base method.
func (*MockStepHandler) GetStepInfo ¶
func (m *MockStepHandler) GetStepInfo(stepName string) interfaces.StepConfig
GetStepInfo mocks base method.
func (*MockStepHandler) Validate ¶
func (m *MockStepHandler) Validate(stepName string, config interfaces.StepConfig) error
Validate mocks base method.
type MockStepHandlerMockRecorder ¶
type MockStepHandlerMockRecorder struct {
// contains filtered or unexported fields
}
MockStepHandlerMockRecorder is the mock recorder for MockStepHandler.
func (*MockStepHandlerMockRecorder) CanHandle ¶
func (mr *MockStepHandlerMockRecorder) CanHandle(stepName any) *gomock.Call
CanHandle indicates an expected call of CanHandle.
func (*MockStepHandlerMockRecorder) Execute ¶
func (mr *MockStepHandlerMockRecorder) Execute(ctx, stepName, config any) *gomock.Call
Execute indicates an expected call of Execute.
func (*MockStepHandlerMockRecorder) GetStepInfo ¶
func (mr *MockStepHandlerMockRecorder) GetStepInfo(stepName any) *gomock.Call
GetStepInfo indicates an expected call of GetStepInfo.
type MockStepRegistry ¶
type MockStepRegistry struct {
// contains filtered or unexported fields
}
MockStepRegistry is a mock of StepRegistry interface.
func NewMockStepRegistry ¶
func NewMockStepRegistry(ctrl *gomock.Controller) *MockStepRegistry
NewMockStepRegistry creates a new mock instance.
func (*MockStepRegistry) EXPECT ¶
func (m *MockStepRegistry) EXPECT() *MockStepRegistryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockStepRegistry) ExecuteStep ¶
func (m *MockStepRegistry) ExecuteStep(ctx context.Context, stepName string) error
ExecuteStep mocks base method.
func (*MockStepRegistry) GetExecutionOrder ¶
func (m *MockStepRegistry) GetExecutionOrder() ([]string, error)
GetExecutionOrder mocks base method.
func (*MockStepRegistry) GetStepConfig ¶
func (m *MockStepRegistry) GetStepConfig(stepName string) (interfaces.StepConfig, error)
GetStepConfig mocks base method.
func (*MockStepRegistry) GetStepHandler ¶
func (m *MockStepRegistry) GetStepHandler(stepName string) (interfaces.StepHandler, error)
GetStepHandler mocks base method.
func (*MockStepRegistry) ListSteps ¶
func (m *MockStepRegistry) ListSteps() []string
ListSteps mocks base method.
func (*MockStepRegistry) RegisterStep ¶
func (m *MockStepRegistry) RegisterStep(stepName string, handler interfaces.StepHandler) error
RegisterStep mocks base method.
func (*MockStepRegistry) ValidateStep ¶
func (m *MockStepRegistry) ValidateStep(stepName string) error
ValidateStep mocks base method.
type MockStepRegistryMockRecorder ¶
type MockStepRegistryMockRecorder struct {
// contains filtered or unexported fields
}
MockStepRegistryMockRecorder is the mock recorder for MockStepRegistry.
func (*MockStepRegistryMockRecorder) ExecuteStep ¶
func (mr *MockStepRegistryMockRecorder) ExecuteStep(ctx, stepName any) *gomock.Call
ExecuteStep indicates an expected call of ExecuteStep.
func (*MockStepRegistryMockRecorder) GetExecutionOrder ¶
func (mr *MockStepRegistryMockRecorder) GetExecutionOrder() *gomock.Call
GetExecutionOrder indicates an expected call of GetExecutionOrder.
func (*MockStepRegistryMockRecorder) GetStepConfig ¶
func (mr *MockStepRegistryMockRecorder) GetStepConfig(stepName any) *gomock.Call
GetStepConfig indicates an expected call of GetStepConfig.
func (*MockStepRegistryMockRecorder) GetStepHandler ¶
func (mr *MockStepRegistryMockRecorder) GetStepHandler(stepName any) *gomock.Call
GetStepHandler indicates an expected call of GetStepHandler.
func (*MockStepRegistryMockRecorder) ListSteps ¶
func (mr *MockStepRegistryMockRecorder) ListSteps() *gomock.Call
ListSteps indicates an expected call of ListSteps.
func (*MockStepRegistryMockRecorder) RegisterStep ¶
func (mr *MockStepRegistryMockRecorder) RegisterStep(stepName, handler any) *gomock.Call
RegisterStep indicates an expected call of RegisterStep.
func (*MockStepRegistryMockRecorder) ValidateStep ¶
func (mr *MockStepRegistryMockRecorder) ValidateStep(stepName any) *gomock.Call
ValidateStep indicates an expected call of ValidateStep.
type MockTestable ¶
type MockTestable struct {
// contains filtered or unexported fields
}
MockTestable is a mock of Testable interface.
func NewMockTestable ¶
func NewMockTestable(ctrl *gomock.Controller) *MockTestable
NewMockTestable creates a new mock instance.
func (*MockTestable) EXPECT ¶
func (m *MockTestable) EXPECT() *MockTestableMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockTestableMockRecorder ¶
type MockTestableMockRecorder struct {
// contains filtered or unexported fields
}
MockTestableMockRecorder is the mock recorder for MockTestable.
type MockVulnChecker ¶
type MockVulnChecker struct {
// contains filtered or unexported fields
}
MockVulnChecker is a mock of VulnChecker interface.
func NewMockVulnChecker ¶
func NewMockVulnChecker(ctrl *gomock.Controller) *MockVulnChecker
NewMockVulnChecker creates a new mock instance.
func (*MockVulnChecker) EXPECT ¶
func (m *MockVulnChecker) EXPECT() *MockVulnCheckerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockVulnCheckerMockRecorder ¶
type MockVulnCheckerMockRecorder struct {
// contains filtered or unexported fields
}
MockVulnCheckerMockRecorder is the mock recorder for MockVulnChecker.